potatoes_secured_preferences
library
Classes
-
AndroidOptions
-
Specific options for Android platform.
-
AppleOptions
-
Specific options for Apple platform.
-
BackgroundTransformer
-
The default Transformer for Dio.
-
BaseOptions
-
A set of base settings for each
Dio().
BaseOptions and Options will be merged into one RequestOptions before
sending the requests. See Options.compose.
-
Bloc<Event, State>
-
Takes a
Stream of Events as input
and transforms them into a Stream of States as output.
-
BlocBase<State>
-
An interface for the core functionality implemented by
both Bloc and Cubit.
-
BlocBuilder<B extends StateStreamable<S>, S>
-
BlocBuilder handles building a widget in response to new
states.
BlocBuilder is analogous to StreamBuilder but has simplified API to
reduce the amount of boilerplate code needed as well as bloc-specific
performance improvements.
Please refer to BlocListener if you want to "do" anything in response to
state changes such as navigation, showing a dialog, etc...
-
BlocBuilderBase<B extends StateStreamable<S>, S>
-
Base class for widgets that build themselves based on interaction with
a specified bloc.
-
BlocConsumer<B extends StateStreamable<S>, S>
-
BlocConsumer exposes a builder and listener in order react to new
states.
BlocConsumer is analogous to a nested
BlocListener
and BlocBuilder but reduces the amount of boilerplate needed.
BlocConsumer should only be used when it is necessary to both rebuild UI
and execute other reactions to state changes in the bloc.
-
BlocEventSink<Event extends Object?>
-
An ErrorSink that supports adding events.
-
BlocListener<B extends StateStreamable<S>, S>
-
Takes a BlocWidgetListener and an optional bloc and invokes
the listener in response to
state changes in the bloc.
It should be used for functionality that needs to occur only in response to
a state change such as navigation, showing a SnackBar, showing
a Dialog, etc...
The listener is guaranteed to only be called once for each state change
unlike the builder in BlocBuilder.
-
BlocListenerBase<B extends StateStreamable<S>, S>
-
Base class for widgets that listen to state changes in a specified bloc.
-
BlocObserver
-
An interface for observing the behavior of Bloc instances.
-
BlocProvider<T extends StateStreamableSource<Object?>>
-
Takes a
create function that is responsible for
creating the Bloc or Cubit and a child which will have access
to the instance via BlocProvider.of(context).
It is used as a dependency injection (DI) widget so that a single instance
of a Bloc or Cubit can be provided to multiple widgets within a subtree.
-
BlocSelector<B extends StateStreamable<S>, S, T>
-
BlocSelector is analogous to BlocBuilder but allows developers to
filter updates by selecting a new value based on the bloc state.
Unnecessary builds are prevented if the selected value does not change.
-
CancelToken
-
Controls cancellation of Dio's requests.
-
Change<State>
-
A Change represents the change from one
State to another.
A Change consists of the currentState and nextState.
-
Closable
-
An object that must be closed when no longer in use.
-
Cubit<State>
-
A Cubit is similar to Bloc but has no notion of events
and relies on methods to emit new states.
-
Dio
-
Dio enables you to make HTTP requests easily.
-
DioForNative
-
Implements features for Dio on native platforms.
-
DioMixin
-
-
Emittable<State extends Object?>
-
An object that can emit new states.
-
EmittableStateStreamableSource<State>
-
A StateStreamableSource that can emit new states.
-
Emitter<State>
-
An Emitter is a class which is capable of emitting new states.
-
Equatable
-
A base class to facilitate operator == and hashCode overrides.
-
EquatableConfig
-
The default configuration for all Equatable instances.
-
ErrorInterceptorHandler
-
The handler for interceptors to handle error occurred during the request.
-
ErrorSink
-
A generic destination for errors.
-
FlutterSecureStorage
-
A class to manage secure storage in a Flutter application across multiple
platforms.
-
FormData
-
A class to create readable "multipart/form-data" streams.
It can be used to submit forms and file uploads to http server.
-
FusedTransformer
-
A Transformer that has a fast path for decoding UTF8-encoded JSON.
If the response is utf8-encoded JSON and no custom decoder is specified in the RequestOptions, this transformer
is significantly faster than the default SyncTransformer and the BackgroundTransformer.
This improvement is achieved by using a fused Utf8Decoder and JsonDecoder to decode the response,
which is faster than decoding the utf8-encoded JSON in two separate steps, since
Dart uses a special fast decoder for this case.
See https://github.com/dart-lang/sdk/blob/5b2ea0c7a227d91c691d2ff8cbbeb5f7f86afdb9/sdk/lib/_internal/vm/lib/convert_patch.dart#L40
-
The headers class for requests and responses.
-
HttpClientAdapter
-
HttpAdapter is a bridge between Dio and HttpClient.
-
Interceptor
-
Interceptor helps to deal with RequestOptions, Response,
and DioException during the lifecycle of a request
before it reaches users.
-
Interceptors
-
A Queue-Model list for Interceptors.
-
InterceptorsWrapper
-
A helper class to create interceptors in ease.
-
IOHttpClientAdapter
-
The default HttpClientAdapter for native platforms.
-
IOSOptions
-
Specific options for iOS platform.
Currently there are no specific ios options available, but only shared
options from apple options.
-
LinuxOptions
-
Specific options for Linux platform.
Currently there are no specific linux options available.
-
ListParam<T>
-
Indicates a param being used as queries or form data,
and how does it gets formatted.
-
LogInterceptor
-
LogInterceptor is used to print logs during network requests.
It should be the last interceptor added,
otherwise modifications by following interceptors will not be logged.
This is because the execution of interceptors is in the order of addition.
-
MacOsOptions
-
Specific options for macOS platform.
Extends
AppleOptions and adds the usesDataProtectionKeychain parameter.
-
MultiBlocListener
-
Merges multiple BlocListener widgets into one widget tree.
-
MultiBlocObserver
-
A BlocObserver which supports registering multiple BlocObserver
instances. This is useful when maintaining multiple BlocObserver instances
for different functions e.g.
LoggingBlocObserver,
ErrorReportingBlocObserver.
-
MultiBlocProvider
-
Merges multiple BlocProvider widgets into one widget tree.
-
MultipartFile
-
An upload content that is a part of
MultipartRequest.
This doesn't need to correspond to a physical file.
-
MultiRepositoryProvider
-
Merges multiple RepositoryProvider widgets into one widget tree.
-
Options
-
The configuration for a single request.
BaseOptions and Options will be merged into one RequestOptions before
sending the requests. See Options.compose.
-
QueuedInterceptor
-
Interceptor in queue.
-
QueuedInterceptorsWrapper
-
A helper class to create QueuedInterceptor in ease.
-
RedirectRecord
-
A record that records the redirection happens during requests,
including status code, request method, and the location.
-
RepositoryProvider<T>
-
Takes a
create function that is responsible for creating the repository
and a child which will have access to the repository via
RepositoryProvider.of(context).
It is used as a dependency injection (DI) widget so that a single instance
of a repository can be provided to multiple widgets within a subtree.
-
RequestInterceptorHandler
-
The handler for interceptors to handle before the request has been sent.
-
RequestOptions
-
The internal request option class that is the eventual result after
BaseOptions and Options are composed.
-
Response<T>
-
The Response class contains the payload (could be transformed)
that respond from the request, and other information of the response.
-
ResponseBody
-
The response wrapper class for adapters.
-
ResponseInterceptorHandler
-
The handler for interceptors to handle after respond.
-
SecuredPreferencesService
-
-
SharedPreferences
-
Wraps NSUserDefaults (on iOS) and SharedPreferences (on Android), providing
a persistent store for simple data.
-
SharedPreferencesAsync
-
Provides a persistent store for simple data.
-
SharedPreferencesOptions
-
Basic options for creating SharedPreferencesAsync classes.
-
SharedPreferencesWithCache
-
Provides a persistent store for simple data.
-
SharedPreferencesWithCacheOptions
-
Options necessary to create a SharedPreferencesWithCache.
-
StateStreamable<State>
-
A Streamable that provides synchronous access to the current state.
-
StateStreamableSource<State>
-
A StateStreamable that must be closed when no longer in use.
-
Streamable<State extends Object?>
-
An object that provides access to a stream of states over time.
-
SyncTransformer
-
If you want to custom the transformation of request/response data,
you can provide a Transformer by your self, and replace
the transformer by setting the Dio.transformer.
-
Transformer
-
Transformer allows changes to the request/response data before
it is sent/received to/from the server.
-
Transition<Event, State>
-
A Transition is the change from one state to another.
Consists of the currentState, an event, and the nextState.
-
WebOptions
-
Specific options for web platform.
-
WindowsOptions
-
Specific options for Windows platform.
Typedefs
-
BlocBuilderCondition<S>
= bool Function(S previous, S current)
-
Signature for the
buildWhen function which takes the previous state and
the current state and is responsible for returning a bool which
determines whether to rebuild BlocBuilder with the current state.
-
BlocListenerCondition<S>
= bool Function(S previous, S current)
-
Signature for the
listenWhen function which takes the previous state
and the current state and is responsible for returning a bool which
determines whether or not to call BlocWidgetListener of BlocListener
with the current state.
-
BlocWidgetBuilder<S>
= Widget Function(BuildContext context, S state)
-
Signature for the
builder function which takes the BuildContext and
state and is responsible for returning a widget which is to be rendered.
This is analogous to the builder function in StreamBuilder.
-
BlocWidgetListener<S>
= void Function(BuildContext context, S state)
-
Signature for the
listener function which takes the BuildContext along
with the state and is responsible for executing in response to
state changes.
-
BlocWidgetSelector<S, T>
= T Function(S state)
-
Signature for the
selector function which
is responsible for returning a selected value, T, based on state.
-
CreateHttpClient
= HttpClient Function()
-
The signature of IOHttpClientAdapter.createHttpClient.
Can be used to provide a custom HttpClient for Dio.
-
DefaultHttpClientAdapter
= IOHttpClientAdapter
-
-
DefaultTransformer
= SyncTransformer
-
-
DioError
= DioException
-
DioError describes the exception info when a request failed.
-
DioErrorType
= DioExceptionType
-
Deprecated in favor of DioExceptionType and will be removed in future major versions.
-
DioExceptionReadableStringBuilder
= String Function(DioException e)
-
The readable string builder's signature of
DioException.readableStringBuilder.
-
DioMediaType
= MediaType
-
The type (alias) for specifying the content-type of the
MultipartFile.
-
EventHandler<Event, State>
= FutureOr<void> Function(Event event, Emitter<State> emit)
-
An event handler is responsible for reacting to an incoming
Event
and can emit zero or more states via the Emitter.
-
EventMapper<Event>
= Stream<Event> Function(Event event)
-
Signature for a function which converts an incoming event
into an outbound stream of events.
Used when defining custom EventTransformers.
-
EventTransformer<Event>
= Stream<Event> Function(Stream<Event> events, EventMapper<Event> mapper)
-
Used to change how events are processed.
By default events are processed concurrently.
-
The signature that iterates header fields.
-
InterceptorErrorCallback
= void Function(DioException error, ErrorInterceptorHandler handler)
-
The signature of Interceptor.onError.
-
InterceptorSendCallback
= void Function(RequestOptions options, RequestInterceptorHandler handler)
-
The signature of Interceptor.onRequest.
-
InterceptorSuccessCallback
= void Function(Response response, ResponseInterceptorHandler handler)
-
The signature of Interceptor.onResponse.
-
JsonDecodeCallback
= FutureOr Function(String)
-
The callback definition for decoding a JSON string.
-
JsonEncodeCallback
= FutureOr<String> Function(Object)
-
The callback definition for encoding a JSON object.
-
OnHttpClientCreate
= HttpClient? Function(HttpClient client)
-
The signature of IOHttpClientAdapter.onHttpClientCreate.
-
ProgressCallback
= void Function(int count, int total)
-
The type of a progress listening callback when sending or receiving data.
-
RequestEncoder
= FutureOr<List<int>> Function(String request, RequestOptions options)
-
The type of a request encoding callback.
-
ResponseDecoder
= FutureOr<String?> Function(List<int> responseBytes, RequestOptions options, ResponseBody responseBody)
-
The type of a response decoding callback.
-
ValidateCertificate
= bool Function(X509Certificate? certificate, String host, int port)
-
The signature of IOHttpClientAdapter.validateCertificate.
-
ValidateStatus
= bool Function(int? status)
-
The type of a response status code validate callback.